@@ -8,9 +8,8 @@ import (
 	. "github.com/onsi/gomega"
 )
 
-func TestFunctional(t *testing.T) {
+func TestSuite(t *testing.T) {
 	RegisterFailHandler(Fail)
-	RunSpecs(t, "Test Suite")
 
 	tc := "[Framework][Functional] Suite"
 	jr := reporters.NewJUnitReporter("/tmp/artifacts/junit/junit-framework-functional.xml")
