@@ -6,11 +6,11 @@ import (
 
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
-	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	"github.com/openshift/cluster-logging-operator/pkg/constants"
+	logging "github.com/openshift/cluster-logging-operator/apis/logging/v1"
+	"github.com/openshift/cluster-logging-operator/internal/constants"
 )
 
-var _ = Describe("[Metrics] Function testing of fluentd metrics", func() {
+var _ = Describe("[SampleCollector] Function testing of fluentd metrics", func() {
 
 	const (
 		sampleMetric = "# HELP fluentd_output_status_buffer_total_bytes"
@@ -33,7 +33,7 @@ var _ = Describe("[Metrics] Function testing of fluentd metrics", func() {
 
 	Context("when using a service address", func() {
 		It("should return successfully", func() {
-			metrics, _ := framework.RunCommand(constants.FluentdName, "curl", "-ksv", fmt.Sprintf("https://%s.%s:24231/metrics", framework.Name, framework.Namespace))
+			metrics, _ := framework.RunCommand(constants.CollectorName, "curl", "-ksv", fmt.Sprintf("https://%s.%s:24231/metrics", framework.Name, framework.Namespace))
 			Expect(metrics).To(ContainSubstring(sampleMetric))
 		})
 	})
