@@ -1,14 +1,14 @@
 package helpers
 
 import (
-	"github.com/openshift/cluster-logging-operator/pkg/constants"
+	"github.com/openshift/cluster-logging-operator/internal/constants"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	clolog "github.com/ViaQ/logerr/log"
-	cl "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	elasticsearch "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
+	cl "github.com/openshift/cluster-logging-operator/apis/logging/v1"
+	elasticsearch "github.com/openshift/elasticsearch-operator/apis/logging/v1"
 )
 
 type LogComponentType string
@@ -24,7 +24,7 @@ func NewClusterLogging(componentTypes ...LogComponentType) *cl.ClusterLogging {
 	instance := &cl.ClusterLogging{
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "ClusterLogging",
-			APIVersion: cl.SchemeGroupVersion.String(),
+			APIVersion: cl.GroupVersion.String(),
 		},
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      constants.SingletonName,
