@@ -1,15 +1,16 @@
 package runtime
 
 import (
-	loggingv1 "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	"github.com/openshift/cluster-logging-operator/pkg/constants"
+	loggingv1 "github.com/openshift/cluster-logging-operator/apis/logging/v1"
+	"github.com/openshift/cluster-logging-operator/internal/constants"
+	"github.com/openshift/cluster-logging-operator/internal/runtime"
 	"github.com/openshift/cluster-logging-operator/test"
 )
 
 // NewClusterLogForwarder returns a ClusterLogForwarder with default name and namespace.
 func NewClusterLogForwarder() *loggingv1.ClusterLogForwarder {
 	clf := &loggingv1.ClusterLogForwarder{}
-	Initialize(clf, constants.OpenshiftNS, constants.SingletonName)
+	runtime.Initialize(clf, constants.OpenshiftNS, constants.SingletonName)
 	return clf
 }
 
@@ -18,7 +19,7 @@ func NewClusterLogForwarder() *loggingv1.ClusterLogForwarder {
 // see ClusterLoggingDefaultXXX to add them.
 func NewClusterLogging() *loggingv1.ClusterLogging {
 	cl := &loggingv1.ClusterLogging{}
-	Initialize(cl, constants.OpenshiftNS, constants.SingletonName)
+	runtime.Initialize(cl, constants.OpenshiftNS, constants.SingletonName)
 	test.MustUnmarshal(`
     collection:
       logs:
